function [a1,b1] = linereg3(t,b)
% Funkcia LINEREG3(t,b) zobrazi regresnu priamku typu y=a+b*x
% a prevedie vypocet optimalnych parametrov 'a' a 'b' metodou
% najmensich stvorcov, kde 't' a 'b' su vektory s rovnakymi dlzkami.
% Zobrazi sa vyrovnavacia priamka datovych bodov (t(i),b(i)).
%
% Priklad pouzitia funkcie:
%                   clear all
%                   load difrak.dat
%                   x = difrak(:,1);
%                   y = difrak(:,2);
%                   linereg2(x,y)
%                   title('Metoda najmensich stvorcov')
%                   xlabel('Vlnova dlzka [pm]')
%                   ylabel('Polomer [mm]')
% 
% Priklad formatu suboru 'difrak.dat':
%                   12.2693	8.1
%                   12.9330	8.3
%                   13.7175	8.6
%                   14.6646	8.9
%                   15.8396	9.6
%                   17.3514	10.9
%                   19.3994	12.4
t=t(:); b=b(:);
n=length(t);
% 'alfa' je zvolena hladina pravdepodobnosti (vyznamnosti) pre
% Studentovo rozdelenie. Viac sa docitate v ucebnom texte
% 'Pravdepodobnost a matematicka statistika v pocitacovom prostredi
% MATLABu', autori Gavalec, Kovacova, Ostertagova, Skrivanek,
% Vydavatelstvo ELFA, Kosice, 2001.
% alfa=.05;
% tinv(1-(alfa/2),n-2)=2.3060
% je "95%-ny interval spolahlivosti" pre regresne koeficiety 'a', 'b'
%%
% Vypocet optimalnej priamky datovych bodov (t(i),b(i))
[fit1,S]=polyfit(t,b,1);
% Graficke zobrazenie
tline = [1.2*min(t)-0.2*max(t) , 1.2*max(t)-0.2*min(t)];
[fit1curve,D]=polyval(fit1,tline,S);
shg
plot(tline,fit1curve,'b-',t,b,'ks')
legend('regresia','experiment',0)
%plot(tline,fit1curve+D,'r-',tline,fit1curve-D,'g-')
b1=fit1(1);
a1=fit1(2);
s0=sum((t.*b1+a1-b).^2)/(n-2);s1=sum(t.^2);s2=sum(t)^2;
sa1=(sqrt((s0*s1)/(n*s1-s2))); % *tinv(1-(alfa/2),n-2);
sb1=(sqrt((n*s0)/(n*s1-s2))); % *tinv(1-(alfa/2),n-2);
if b1 >= 0 , sign = ' + '; else, sign = ' - '; end
% Vypisanie vysledkov
scaley=(1.2*max(b)-0.2*min(b))-(1.2*min(b)-0.2*max(b));
text(t(1),b(n),['y = ' num2str(a1,4) sign num2str(abs(b1),4) '*x'])
text(t(1),b(n)-scaley/20,['a = ' num2str(a1,4) ' \pm ' num2str(sa1,4)])
text(t(1),b(n)-scaley/10,['b = ' sign num2str(abs(b1),4) ' \pm ' num2str(sb1,4)])
