function linereg2(t,u)
% Funkcia LINEREG2(t,u) zobrazi regresnu priamku typu y=a+b*x
% a prevedie vypocet optimalnych parametrov 'a' a 'b' metodou
% najmensich stvorcov, kde 't' a 'u' su vektory s rovnakymi dlzkami.
% Zobrazi sa vyrovnavacia priamka datovych bodov (t(i),u(i)).
%
% Priklad pouzitia funkcie:
%                   clear all
%                   load q1.dat
%                   x = q1(:,1);
%                   y = q1(:,2);
%                   linereg2(x,y)
%                   title('Metoda najmensich stvorcov')
%                   xlabel('Vlnova dlzka \lambda (m)')
%                   ylabel('Polomer (m)')
% 
% Priklad formatu suboru 'q1.dat':
%                   12.3E-12	8.0E-03
%                   12.9E-12	8.5E-03
%                   13.7E-12	9.0E-03
%                   14.7E-12	9.5E-03
%                   16.0E-12	10.0E-03
%                   17.0E-12	11.0E-03
%                   19.0E-12	11.5E-03
%                   22.4E-12	13.0E-03

t=t(:); u=u(:);
n=length(t);

% 'alfa' je zvolena hladina pravdepodobnosti (vyznamnosti) pre
% Studentovo rozdelenie. Viac sa docitate v ucebnom texte
% 'Pravdepodobnost a matematicka statistika v pocitacovom prostredi
% MATLABu', autori Gavalec, Kovacova, Ostertagova, Skrivanek,
% Vydavatelstvo ELFA, Kosice, 2001.
% alfa=.05;
% tinv(1-(alfa/2),n-2)=2.3060
% je "95%-ny interval spolahlivosti" pre regresne koeficiety 'a', 'b'
%%
% Vypocet optimalnej priamky datovych bodov (t(i),u(i))
[fit1,S]=polyfit(t,u,1);
% Graficke zobrazenie
tline = [1.2*min(t)-0.2*max(t) , 1.2*max(t)-0.2*min(t)];
[fit1curve,D]=polyval(fit1,tline,S);
shg
plot(tline,fit1curve,'b-',t,u,'ks')
legend('regresia','experiment',4)
%plot(tline,fit1curve+D,'r-',tline,fit1curve-D,'g-')
b1=fit1(1);
a1=fit1(2);
s0=sum((t.*b1+a1-u).^2)/(n-2);s1=sum(t.^2);s2=sum(t)^2;
% Standardne neistoty parametrov 'a' a 'b' priamky y=a+b*x
sa1=(sqrt((s0*s1)/(n*s1-s2))); % *tinv(1-(alfa/2),n-2);
sb1=(sqrt((n*s0)/(n*s1-s2))); % *tinv(1-(alfa/2),n-2);
if b1 >= 0 , sign = ' + '; else, sign = ' - '; end
% Vypisanie vysledkov
scaley=(1.2*max(u)-0.2*min(u))-(1.2*min(u)-0.2*max(u));
text(t(1),u(n),['y = ' num2str(a1,4) sign num2str(abs(b1),4) '*x'])
text(t(1),u(n)-scaley/20,['a = ' num2str(a1,4) ' \pm ' num2str(sa1,4)])
text(t(1),u(n)-scaley/10,['b = ' sign num2str(abs(b1),4) ' \pm ' num2str(sb1,4)])
%%